@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include "PYEnglishEditor.h"
@@ -358,7 +358,7 @@ EnglishEditor::EnglishEditor (PinyinProperties & props, Config &config)
                                      "ibus", "pinyin", "english-user.db", NULL);
 
     gboolean result = m_english_database->openDatabase
-        (".." G_DIR_SEPARATOR_S "data" G_DIR_SEPARATOR_S "english.db",
+        (".." G_DIR_SEPARATOR_S "data" G_DIR_SEPARATOR_S "db" G_DIR_SEPARATOR_S "english" G_DIR_SEPARATOR_S "english.db",
          "english-user.db") ||
         m_english_database->openDatabase
         (PKGDATADIR G_DIR_SEPARATOR_S "db" G_DIR_SEPARATOR_S "english.db", path);
@@ -375,6 +375,9 @@ EnglishEditor::~EnglishEditor ()
 gboolean
 EnglishEditor::processKeyEvent (guint keyval, guint keycode, guint modifiers)
 {
+    if (modifiers & IBUS_MOD4_MASK)
+        return FALSE;
+
     //IBUS_SHIFT_MASK is removed.
     modifiers &= (IBUS_CONTROL_MASK |
                   IBUS_MOD1_MASK |
