@@ -76,6 +76,9 @@ ExtEditor::resetLuaState ()
 gboolean
 ExtEditor::processKeyEvent (guint keyval, guint keycode, guint modifiers)
 {
+    if (modifiers & IBUS_MOD4_MASK)
+        return FALSE;
+
     //IBUS_SHIFT_MASK is removed.
     modifiers &= (IBUS_CONTROL_MASK |
                   IBUS_MOD1_MASK |
@@ -494,7 +497,7 @@ ExtEditor::updateStateFromInput (void)
         return FALSE;
     }
 
-    if ( ! 'i' == m_text[0] ) {
+    if (m_text[0] != 'i') {
         g_warning ("i is expected in m_text string.\n");
         return FALSE;
     }
