@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #ifndef __PY_FULL_PINYIN_EDITOR_H_
 #define __PY_FULL_PINYIN_EDITOR_H_
@@ -32,31 +32,6 @@ class FullPinyinEditor : public PinyinEditor {
 public:
     FullPinyinEditor (PinyinProperties & props, Config & config);
     ~FullPinyinEditor (void);
-
-public:
-    /* virtual functions */
-#if 0
-    virtual gboolean processKeyEvent (guint keyval, guint keycode, guint modifiers);
-#endif
-    virtual void reset (void);
-
-protected:
-    gboolean insert (gint ch);
-
-    gboolean removeCharBefore (void);
-    gboolean removeCharAfter (void);
-    gboolean removeWordBefore (void);
-    gboolean removeWordAfter (void);
-
-    gboolean moveCursorLeft (void);
-    gboolean moveCursorRight (void);
-    gboolean moveCursorLeftByWord (void);
-    gboolean moveCursorRightByWord (void);
-    gboolean moveCursorToBegin (void);
-    gboolean moveCursorToEnd (void);
-
-    void updatePinyin (void);
-
 };
 
 };
